@@ -19,7 +19,7 @@ __credits__ = """"""
 #    http://www.gnu.org/copyleft/lesser.html
 import os
 import sys
-from networkx.io import _get_fh
+from networkx.utils import _get_fh
 try:
     import pygraphviz
 except ImportError:
@@ -235,7 +235,7 @@ def pygraphviz_layout(G,prog='neato',root=None, args=''):
     
     """
     A=to_agraph(G)
-    A.layout(prog=prog)
+    A.layout(prog=prog,args=args)
     node_pos={}
     for n in G.nodes():
         node=pygraphviz.Node(A,n)
