@@ -1,6 +1,6 @@
 """Release data for NetworkX."""
 
-#    Copyright (C) 2004-2006 by 
+#    Copyright (C) 2004-2007 by 
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
@@ -8,10 +8,9 @@
 #    http://www.gnu.org/copyleft/lesser.html
 
 __author__ = """Aric Hagberg (hagberg@lanl.gov)\nPieter Swart (swart@lanl.gov)\nDan Schult (dschult@colgate.edu)"""
-__date__ = "$Date: 2006-09-29 08:59:14 -0600 (Fri, 29 Sep 2006) $"
 
 name = 'networkx'
-version = '0.32'
+version = '0.35.1'
 
 description = "Python package for creating and manipulating graphs and networks"
 
@@ -27,9 +26,23 @@ authors = {'Hagberg' : ('Aric Hagberg','hagberg@lanl.gov'),
            'Swart' : ('Pieter Swart','swart@lanl.gov')
            }
 url = 'http://networkx.lanl.gov/'
-download_url="http://sourceforge.net/project/showfiles.php?group_id=122233"
+download_url="http://networkx.lanl.gov/download"
 platforms = ['Linux','Mac OSX','Windows XP/2000/NT']
 keywords = ['Networks', 'Graph Theory', 'Mathematics', 'network', 'graph', 'discrete mathematics', 'math']
+classifiers = [
+        'Development Status :: 4 - Beta',
+        'Intended Audience :: Developers',
+        'Intended Audience :: Science/Research',
+        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
+        'Operating System :: OS Independent',
+        'Programming Language :: Python',
+        'Topic :: Software Development :: Libraries :: Python Modules',
+        'Topic :: Scientific/Engineering :: Bio-Informatics',
+        'Topic :: Scientific/Engineering :: Information Analysis',
+        'Topic :: Scientific/Engineering :: Mathematics',
+        'Topic :: Scientific/Engineering :: Physics',
+        ]
+
 # Get date dynamically
 import time
 date = time.asctime()
